@@ -8,6 +8,9 @@ class ArduinoNotSuppliedException(Exception):
 class ServoOutOfRangeException(Exception):
   pass
 
+class InvalidPercentageException(Exception):
+  pass
+
 class Component(EventEmitter):
 
   def __init__(self, board, pin):
@@ -92,10 +95,13 @@ class Led(Component):
     self._interval = setInterval(self.toggle, millis)
 
   def brightness(self, value):
+    if int(value) > 100 or int(value) < 0:
+      raise InvalidPercentageException
+
     if self._pin.mode != pyfirmata.PWM:
       self._pin.mode = pyfirmata.PWM
 
-    _new_value = value / 255.0
+    _new_value = value / 100.0
 
     if _new_value == 0:
       self._isOn = False
@@ -214,3 +220,29 @@ class Servo(Component):
 
   def reset(self):
     self.set_position(0)
+
+class Motor(Component):
+
+  def __init__(self, board, pin):
+    super(Motor, self).__init__(board, pin)
+    self._speed = 0
+    self._pin.mode = pyfirmata.PWM
+
+  def start(self, speed=50):
+    self.speed = speed
+
+  def stop(self):
+    self.speed = 0
+
+  @property
+  def speed(self):
+    return self._speed
+
+  @speed.setter
+  def speed(self, speed):
+    if int(speed) > 100 or int(speed) < 0:
+      raise InvalidPercentageException
+
+    self._speed = speed
+    self._pin.write(speed / 100.0)
+    self.emit('change', speed)
